OC.L10N.register(
    "circles",
    {
    "Personal" : "Persoonlik",
    "System" : "Stelsel",
    "Visible" : "Sigbaar",
    "Open" : "Open",
    "Hidden" : "Versteek",
    "Email address" : "E-posadres",
    "Contact" : "Kontak",
    "Admin" : "Admin",
    "Owner" : "Eienaar",
    "Open »%s«" : "Open »%s«",
    "Accept" : "Aanvaar",
    "No files in here" : "Geen lêers hier nie",
    "No entries found in this folder" : "Geen inskrwyings in hierdie gids gevind",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Gewysig",
    "now" : "nou"
},
"nplurals=2; plural=(n != 1);");
